@@ -98,8 +98,8 @@ class EnterpriseLearnerEnrollment(models.Model):
     coupon_code = models.CharField(max_length=128, null=True)
     coupon_name = models.CharField(max_length=128, null=True)
     contract_id = models.CharField(max_length=128, null=True)
-    course_list_price = models.DecimalField(decimal_places=2, max_digits=12, null=True)
-    amount_learner_paid = models.DecimalField(decimal_places=2, max_digits=12, null=True)
+    course_list_price = models.FloatField(null=True)
+    amount_learner_paid = models.FloatField(null=True)
     course_key = models.CharField(max_length=255, null=False, db_index=True)
     courserun_key = models.CharField(max_length=255, null=False, db_index=True)
     course_title = models.CharField(max_length=255, null=True, db_index=True)
